PDFstream
=========

![test](https://github.com/xpdAcq/PDFstream/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/xpdAcq/PDFstream/branch/master/graph/badge.svg?token=ZFXWWDWQW8)](https://codecov.io/gh/xpdAcq/PDFstream)
[![Anaconda-Server Badge](https://anaconda.org/nsls2forge/pdfstream/badges/version.svg)](https://anaconda.org/nsls2forge/pdfstream)

The data analysis toolbox for the study on pair distribution function (PDF).

-   Free software: 3-clause BSD license
-   Documentation: <https://xpdacq.github.io/PDFstream/>.
